@@ -1,13 +1,13 @@
 /*
  *  birthdaydlg.h  -  dialog to pick birthdays from address book
  *  Program:  kalarm
- *  SPDX-FileCopyrightText: 2002-2020 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2002-2022 David Jarvie <djarvie@kde.org>
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 #pragma once
 
-#include <KAlarmCal/KAEvent>
+#include "kalarmcalendar/kaevent.h"
 
 #include <KLineEdit>
 
@@ -80,5 +80,4 @@ protected:
     void focusOutEvent(QFocusEvent*) override { Q_EMIT focusLost(); }
 };
 
-
 // vim: et sw=4:
