@@ -9,13 +9,17 @@
 #pragma once
 
 #include <phonon/phononnamespace.h>
-#include <phonon/path.h>
+#include <phonon/Path>
 #include <QObject>
 #include <QMutex>
 
 class MessageDisplayHelper;
 
-namespace Phonon { class MediaObject; }
+namespace Phonon
+{
+    class MediaObject;
+    class VolumeFaderEffect;
+}
 
 // Class to play an audio file, optionally repeated.
 class AudioPlayer : public QObject
@@ -27,26 +31,32 @@ public:
     void    execute();
     QString error() const;
 
+public Q_SLOTS:
+    void    stop();
+
 Q_SIGNALS:
     void    readyToPlay();
 
 private Q_SLOTS:
     void    checkAudioPlay();
     void    playStateChanged(Phonon::State);
-    void    stopPlay();
 
 private:
+    void    removeEffects();
+
     mutable QMutex       mMutex;
     QString              mFile;
     float                mVolume;
     float                mFadeVolume;
     int                  mFadeSeconds;
     int                  mRepeatPause;
-    Phonon::MediaObject* mAudioObject;
+    Phonon::MediaObject* mAudioObject {nullptr};
     Phonon::Path         mPath;
+    Phonon::VolumeFaderEffect* mFader {nullptr};
     QString              mError;
     bool                 mPlayedOnce;   // the sound file has started playing at least once
     bool                 mPausing;      // currently pausing between repeats
+    bool                 mStopping {false};  // the player is about to be deleted
 };
 
 // vim: et sw=4:
