@@ -1,7 +1,7 @@
 /*
  *  preferences.h  -  program preference settings
  *  Program:  kalarm
- *  SPDX-FileCopyrightText: 2001-2021 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2001-2022 David Jarvie <djarvie@kde.org>
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
  */
@@ -9,8 +9,7 @@
 #pragma once
 
 #include "kalarmconfig.h"
-
-#include <KAlarmCal/KADateTime>
+#include "kalarmcalendar/kadatetime.h"
 
 #include <QObject>
 #include <QDateTime>
@@ -80,6 +79,8 @@ public:
     static bool             emailBccUseSystemSettings();
     static QString          cmdXTermCommand();
     static void             setCmdXTermCommand(const QString& cmd);
+    static SoundType        defaultSoundType();
+    static void             setDefaultSoundType(SoundType);
     static float            defaultSoundVolume()             { int vol = self()->mBase_DefaultSoundVolume; return (vol < 0) ? -1 : static_cast<float>(vol) / 100; }
     static void             setDefaultSoundVolume(float v)   { self()->setBase_DefaultSoundVolume(v < 0 ? -1 : static_cast<int>(v * 100)); }
 
@@ -121,5 +122,4 @@ private:
     static bool             mAutoStartChangedByUser; // AutoStart has been changed by the user
 };
 
-
 // vim: et sw=4:
