@@ -1,7 +1,7 @@
 /*
  *  templatelistview.cpp  -  widget showing list of alarm templates
  *  Program:  kalarm
- *  SPDX-FileCopyrightText: 2007-2020 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2007-2021 David Jarvie <djarvie@kde.org>
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
  */
@@ -39,7 +39,7 @@ void TemplateListView::initSections()
     sortByColumn(TemplateListModel::TemplateNameColumn, Qt::AscendingOrder);
 }
 
-void TemplateListDelegate::edit(KAEvent* event, EventListView* view)
+void TemplateListDelegate::edit(KAEvent& event, EventListView* view)
 {
     KAlarm::editTemplate(event, static_cast<TemplateListView*>(view));
 }
